@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use base qw{ Exporter };
 
-our $VERSION = '0.005_04';
+our $VERSION = '0.006_01';
 
 our @CARP_NOT = qw{
     PPIx::QuoteLike
@@ -27,11 +27,22 @@ our @CARP_NOT = qw{
 
 our @EXPORT_OK = qw{
     MINIMUM_PERL
+    HAVE_PPIX_REGEXP
     SUFFICIENT_UTF8_SUPPORT_FOR_WEIRD_DELIMITERS
     VARIABLE_RE
     @CARP_NOT
 };
 
+# We can't depend on PPIx::Regexp without getting into a circular
+# dependency. I think. But we can sure use it if we can come by it.
+use constant HAVE_PPIX_REGEXP	=> do {
+    local $@ = undef;
+    eval {	## no critic (RequireCheckingReturnValueOfEval)
+	require PPIx::Regexp;
+	1;
+    };
+};
+
 use constant MINIMUM_PERL	=> '5.000';
 
 use constant SUFFICIENT_UTF8_SUPPORT_FOR_WEIRD_DELIMITERS => $] ge '5.008003';
@@ -110,7 +121,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2018 by Thomas R. Wyant, III
+Copyright (C) 2016-2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
